JBoss Rich Faces SVN: r12945 - trunk/ui/columns/src/main/java/org/richfaces/taglib.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 15:38:26 -0400 (Thu, 12 Mar 2009)
New Revision: 12945
Modified:
trunk/ui/columns/src/main/java/org/richfaces/taglib/ColumnsHandler.java
Log:
https://jira.jboss.org/jira/browse/RF-6040
Modified: trunk/ui/columns/src/main/java/org/richfaces/taglib/ColumnsHandler.java
===================================================================
--- trunk/ui/columns/src/main/java/org/richfaces/taglib/ColumnsHandler.java 2009-03-12 17:59:09 UTC (rev 12944)
+++ trunk/ui/columns/src/main/java/org/richfaces/taglib/ColumnsHandler.java 2009-03-12 19:38:26 UTC (rev 12945)
@@ -214,35 +214,35 @@
*/
private void prepare(FaceletContext ctx) {
- initVariables(ctx);
-
- IterationContext itContext = getIterationContext();
+ initVariables(ctx);
- try {
+ IterationContext itContext = getIterationContext();
- this.value = getAttribute("value");
- itContext.valueExpr = ELBuilder.getVarReplacement(this.value.getValue());
+ try {
- // produce the right sort of ForEachIterator
- if (value != null) {
- // If this is a deferred expression, make a note and get
- // the 'items' instance.
+ this.value = getAttribute("value");
- itContext.rawItems = value.getObject(ctx);
+ // produce the right sort of ForEachIterator
+ if (this.value != null) {
+ itContext.valueExpr = ELBuilder.getVarReplacement(this.value.getValue());
- // extract an iterator over the 'items' we've got
- itContext.items = SimpleForEachIterator
- .supportedTypeForEachIterator(itContext.rawItems);
- } else {
- // no 'items', so use 'begin' and 'end'
- itContext.items = SimpleForEachIterator
- .beginEndForEachIterator(itContext._columns - 1);
- }
- } catch (Exception e) {
- // TODO: handle exception
- }
+ // If this is a deferred expression, make a note and get
+ // the 'items' instance.
- correctFirst(ctx);
+ itContext.rawItems = this.value.getObject(ctx);
+
+ // extract an iterator over the 'items' we've got
+ itContext.items = SimpleForEachIterator
+ .supportedTypeForEachIterator(itContext.rawItems);
+ } else {
+ // no 'items', so use 'begin' and 'end'
+ itContext.items = SimpleForEachIterator.beginEndForEachIterator(itContext._columns - 1);
+ }
+ } catch (Exception e) {
+ // TODO: handle exception
+ }
+
+ correctFirst(ctx);
}
/**
15 years, 10 months
JBoss Rich Faces SVN: r12944 - in trunk/sandbox: ui and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 13:59:09 -0400 (Thu, 12 Mar 2009)
New Revision: 12944
Removed:
trunk/sandbox/samples/colorPickerDemo/
trunk/sandbox/ui/colorPicker/
Modified:
trunk/sandbox/ui/pom.xml
Log:
ColorPicker being moved to main build
Modified: trunk/sandbox/ui/pom.xml
===================================================================
--- trunk/sandbox/ui/pom.xml 2009-03-12 17:58:32 UTC (rev 12943)
+++ trunk/sandbox/ui/pom.xml 2009-03-12 17:59:09 UTC (rev 12944)
@@ -18,7 +18,6 @@
<module>rex-messageBox</module>
<!--module>rex-button</module-->
<module>sortableHeader</module>
- <module>colorPicker</module>
<module>layout</module>
</modules>
</project>
\ No newline at end of file
15 years, 10 months
JBoss Rich Faces SVN: r12943 - in trunk/samples: colorPickerDemo and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 13:58:32 -0400 (Thu, 12 Mar 2009)
New Revision: 12943
Added:
trunk/samples/colorPickerDemo/
Modified:
trunk/samples/colorPickerDemo/pom.xml
trunk/samples/pom.xml
Log:
ColorPicker being moved to main build
Copied: trunk/samples/colorPickerDemo (from rev 12941, trunk/sandbox/samples/colorPickerDemo)
Modified: trunk/samples/colorPickerDemo/pom.xml
===================================================================
--- trunk/sandbox/samples/colorPickerDemo/pom.xml 2009-03-12 17:51:50 UTC (rev 12941)
+++ trunk/samples/colorPickerDemo/pom.xml 2009-03-12 17:58:32 UTC (rev 12943)
@@ -1,17 +1,16 @@
<?xml version="1.0"?><project>
<parent>
<artifactId>samples</artifactId>
- <groupId>org.richfaces.sandbox</groupId>
+ <groupId>org.richfaces</groupId>
<version>3.3.1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
- <groupId>org.richfaces.sandbox.samples</groupId>
- <artifactId>colorPicker</artifactId>
+ <groupId>org.richfaces.samples</groupId>
+ <artifactId>colorPickerDemo</artifactId>
<packaging>war</packaging>
<name>colorPicker Maven Webapp</name>
- <version>1.0-SNAPSHOT</version>
<build>
- <finalName>colorPicker</finalName>
+ <finalName>colorPickerDemo</finalName>
<plugins>
<plugin>
<artifactId>maven-compiler-plugin</artifactId>
@@ -39,10 +38,5 @@
<artifactId>richfaces-impl</artifactId>
<version>3.3.1-SNAPSHOT</version>
</dependency>
- <dependency>
- <groupId>org.richfaces.sandbox.ui</groupId>
- <artifactId>colorPicker</artifactId>
- <version>1.0-SNAPSHOT</version>
- </dependency>
</dependencies>
</project>
Modified: trunk/samples/pom.xml
===================================================================
--- trunk/samples/pom.xml 2009-03-12 17:55:55 UTC (rev 12942)
+++ trunk/samples/pom.xml 2009-03-12 17:58:32 UTC (rev 12943)
@@ -486,6 +486,7 @@
<module>queue-sample</module>
<module>editor-sample</module>
<module>editorSeam-sample</module>
+ <module>colorPickerDemo</module>
</modules>
</profile>
</profiles>
15 years, 10 months
JBoss Rich Faces SVN: r12942 - in trunk/ui: colorPicker and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 13:55:55 -0400 (Thu, 12 Mar 2009)
New Revision: 12942
Added:
trunk/ui/colorPicker/
Modified:
trunk/ui/colorPicker/pom.xml
trunk/ui/pom.xml
Log:
ColorPicker being moved to main build
Copied: trunk/ui/colorPicker (from rev 12931, trunk/sandbox/ui/colorPicker)
Modified: trunk/ui/colorPicker/pom.xml
===================================================================
--- trunk/sandbox/ui/colorPicker/pom.xml 2009-03-12 10:57:04 UTC (rev 12931)
+++ trunk/ui/colorPicker/pom.xml 2009-03-12 17:55:55 UTC (rev 12942)
@@ -1,14 +1,12 @@
<?xml version="1.0"?><project>
<parent>
<artifactId>ui</artifactId>
- <groupId>org.richfaces.sandbox</groupId>
+ <groupId>org.richfaces</groupId>
<version>3.3.1-SNAPSHOT</version>
</parent>
<modelVersion>4.0.0</modelVersion>
- <groupId>org.richfaces.sandbox.ui</groupId>
+ <groupId>org.richfaces.ui</groupId>
<artifactId>colorPicker</artifactId>
- <name>colorPicker</name>
- <version>1.0-SNAPSHOT</version>
<build>
<plugins>
<plugin>
@@ -44,7 +42,7 @@
<dependency>
<groupId>org.richfaces.framework</groupId>
<artifactId>richfaces-impl</artifactId>
- <version>3.3.1-SNAPSHOT</version>
+ <version>${project.version}</version>
</dependency>
</dependencies>
</project>
Modified: trunk/ui/pom.xml
===================================================================
--- trunk/ui/pom.xml 2009-03-12 17:51:50 UTC (rev 12941)
+++ trunk/ui/pom.xml 2009-03-12 17:55:55 UTC (rev 12942)
@@ -83,6 +83,7 @@
</profiles>
<modules>
<module>core</module>
+ <module>colorPicker</module>
<module>drag-drop</module>
<module>effect</module>
<module>panel</module>
15 years, 10 months
JBoss Rich Faces SVN: r12941 - trunk/sandbox/samples.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 13:51:50 -0400 (Thu, 12 Mar 2009)
New Revision: 12941
Added:
trunk/sandbox/samples/colorPickerDemo/
Removed:
trunk/sandbox/samples/colorPicker/
Log:
ColorPicker being moved to main build
Copied: trunk/sandbox/samples/colorPickerDemo (from rev 12931, trunk/sandbox/samples/colorPicker)
15 years, 10 months
JBoss Rich Faces SVN: r12940 - in trunk: extensions/gwt and 11 other directories.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 13:42:39 -0400 (Thu, 12 Mar 2009)
New Revision: 12940
Modified:
trunk/cdk/generator/pom.xml
trunk/extensions/gwt/pom.xml
trunk/framework/pom.xml
trunk/framework/test/pom.xml
trunk/samples/dataTableDemo/pom.xml
trunk/samples/pom.xml
trunk/samples/richfaces-demo/pom.xml
trunk/samples/richfaces-ear-demo/webapp/pom.xml
trunk/samples/seamEAR/wars/seamWebapp/pom.xml
trunk/sandbox/samples/rex-demo/pom.xml
trunk/test-applications/seamApp/web/pom.xml
trunk/test-applications/seleniumTest/pom.xml
trunk/ui/pom.xml
Log:
JSF Updated to 1.2.12
Modified: trunk/cdk/generator/pom.xml
===================================================================
--- trunk/cdk/generator/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/cdk/generator/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -52,7 +52,7 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.servlet.jsp</groupId>
Modified: trunk/extensions/gwt/pom.xml
===================================================================
--- trunk/extensions/gwt/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/extensions/gwt/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -120,12 +120,12 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
Modified: trunk/framework/pom.xml
===================================================================
--- trunk/framework/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/framework/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -99,7 +99,7 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
<dependency>
Modified: trunk/framework/test/pom.xml
===================================================================
--- trunk/framework/test/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/framework/test/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -47,7 +47,7 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>net.sourceforge.htmlunit</groupId>
Modified: trunk/samples/dataTableDemo/pom.xml
===================================================================
--- trunk/samples/dataTableDemo/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/samples/dataTableDemo/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -16,10 +16,15 @@
<dependencies>
<dependency>
<groupId>org.richfaces.ui</groupId>
- <artifactId>richfaces-ui</artifactId>
+ <artifactId>core</artifactId>
<version>${project.version}</version>
</dependency>
<dependency>
+ <groupId>org.richfaces.ui</groupId>
+ <artifactId>dataTable</artifactId>
+ <version>${project.version}</version>
+ </dependency>
+ <dependency>
<groupId>org.richfaces.samples</groupId>
<artifactId>skins</artifactId>
<version>${project.version}</version>
Modified: trunk/samples/pom.xml
===================================================================
--- trunk/samples/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/samples/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -183,12 +183,12 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -238,12 +238,12 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -283,12 +283,12 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>runtime</scope>
</dependency>
<dependency>
@@ -337,13 +337,13 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
</dependencies>
Modified: trunk/samples/richfaces-demo/pom.xml
===================================================================
--- trunk/samples/richfaces-demo/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/samples/richfaces-demo/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -184,12 +184,12 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -280,12 +280,12 @@
<!-- dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>runtime</scope>
</dependency -->
<dependency>
Modified: trunk/samples/richfaces-ear-demo/webapp/pom.xml
===================================================================
--- trunk/samples/richfaces-ear-demo/webapp/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/samples/richfaces-ear-demo/webapp/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -93,13 +93,13 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
</dependencies>
Modified: trunk/samples/seamEAR/wars/seamWebapp/pom.xml
===================================================================
--- trunk/samples/seamEAR/wars/seamWebapp/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/samples/seamEAR/wars/seamWebapp/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -55,13 +55,13 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
<dependency>
Modified: trunk/sandbox/samples/rex-demo/pom.xml
===================================================================
--- trunk/sandbox/samples/rex-demo/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/sandbox/samples/rex-demo/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -163,12 +163,12 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>runtime</scope>
</dependency>
</dependencies>
Modified: trunk/test-applications/seamApp/web/pom.xml
===================================================================
--- trunk/test-applications/seamApp/web/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/test-applications/seamApp/web/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -16,13 +16,13 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
<dependency>
Modified: trunk/test-applications/seleniumTest/pom.xml
===================================================================
--- trunk/test-applications/seleniumTest/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/test-applications/seleniumTest/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -232,7 +232,7 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-impl</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
</dependency>
<dependency>
<groupId>org.hibernate</groupId>
Modified: trunk/ui/pom.xml
===================================================================
--- trunk/ui/pom.xml 2009-03-12 16:55:23 UTC (rev 12939)
+++ trunk/ui/pom.xml 2009-03-12 17:42:39 UTC (rev 12940)
@@ -183,7 +183,7 @@
<dependency>
<groupId>javax.faces</groupId>
<artifactId>jsf-api</artifactId>
- <version>1.2_11</version>
+ <version>1.2_12</version>
<scope>provided</scope>
</dependency>
</dependencies>
15 years, 10 months
JBoss Rich Faces SVN: r12939 - in trunk/ui/fileUpload/src/main/java/org/richfaces: renderkit and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 12:55:23 -0400 (Thu, 12 Mar 2009)
New Revision: 12939
Modified:
trunk/ui/fileUpload/src/main/java/org/richfaces/component/UIFileUpload.java
trunk/ui/fileUpload/src/main/java/org/richfaces/renderkit/FileUploadRendererBase.java
Log:
https://jira.jboss.org/jira/browse/RF-4761
Modified: trunk/ui/fileUpload/src/main/java/org/richfaces/component/UIFileUpload.java
===================================================================
--- trunk/ui/fileUpload/src/main/java/org/richfaces/component/UIFileUpload.java 2009-03-12 16:54:08 UTC (rev 12938)
+++ trunk/ui/fileUpload/src/main/java/org/richfaces/component/UIFileUpload.java 2009-03-12 16:55:23 UTC (rev 12939)
@@ -202,19 +202,21 @@
Map<String, Object> sessionMap = externalContext.getSessionMap();
- Map<String, MultipartRequest> sessions = (Map<String, MultipartRequest>) sessionMap
- .get(FileUploadConstants.REQUESTS_SESSIONS_BEAN_NAME);
- if (sessions != null) {
- MultipartRequest multipartRequest = sessions.get(uid);
- if (multipartRequest != null) {
- if ("progress".equals(actionString)) {
- setupProgressBarValueExpression(facesContext, uid);
- ajaxContext.setResponseData(multipartRequest.getSize());
- } else if ("richfaces_file_upload_action_stop".equals(actionString)) {
- multipartRequest.stop();
- }
- }
- }
+ if ("progress".equals(actionString)) {
+ setupProgressBarValueExpression(facesContext, uid);
+ Map<String, Integer> requestsSizeMap = (Map<String, Integer>) sessionMap.get(FileUploadConstants.REQUEST_SIZE_BEAN_NAME);
+
+ if (requestsSizeMap != null) {
+ ajaxContext.setResponseData(requestsSizeMap.get(uid));
+ } else {
+ ajaxContext.setResponseData(null);
+ }
+ } else if (FileUploadConstants.FILE_UPLOAD_ACTION_STOP.equals(actionString)) {
+ MultipartRequest multipartRequest = MultipartRequest.lookupRequest(facesContext, uid);
+ if (multipartRequest != null) {
+ multipartRequest.stop();
+ }
+ }
}
}
Modified: trunk/ui/fileUpload/src/main/java/org/richfaces/renderkit/FileUploadRendererBase.java
===================================================================
--- trunk/ui/fileUpload/src/main/java/org/richfaces/renderkit/FileUploadRendererBase.java 2009-03-12 16:54:08 UTC (rev 12938)
+++ trunk/ui/fileUpload/src/main/java/org/richfaces/renderkit/FileUploadRendererBase.java 2009-03-12 16:55:23 UTC (rev 12939)
@@ -133,11 +133,9 @@
String uid = requestParameterMap.get(FileUploadConstants.UPLOAD_FILES_ID);
decreaseFileCounter(context, id);
- Map<String, MultipartRequest> map = (Map<String, MultipartRequest>) externalContext.getSessionMap()
- .get(FileUploadConstants.REQUESTS_SESSIONS_BEAN_NAME);
-
- MultipartRequest multipartRequest = map.get(uid);
+ MultipartRequest multipartRequest = MultipartRequest.lookupRequest(context, uid);
+
boolean isFlash = (requestParameterMap.get("_richfaces_send_http_error") != null);
List<UploadItem> fileList = multipartRequest.getUploadItems();
15 years, 10 months
JBoss Rich Faces SVN: r12938 - trunk/framework/impl/src/main/java/org/ajax4jsf/request.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 12:54:08 -0400 (Thu, 12 Mar 2009)
New Revision: 12938
Modified:
trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java
Log:
https://jira.jboss.org/jira/browse/RF-4761
Modified: trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java
===================================================================
--- trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java 2009-03-12 16:53:32 UTC (rev 12937)
+++ trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java 2009-03-12 16:54:08 UTC (rev 12938)
@@ -33,7 +33,7 @@
* @since 3.3.1
*/
-public class MultipartRequestRegistry {
+class MultipartRequestRegistry {
private AtomicInteger atomicInteger = new AtomicInteger(0);
15 years, 10 months
JBoss Rich Faces SVN: r12937 - in trunk/framework/impl/src/main/java/org: richfaces/component and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2009-03-12 12:53:32 -0400 (Thu, 12 Mar 2009)
New Revision: 12937
Added:
trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java
Modified:
trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequest.java
trunk/framework/impl/src/main/java/org/richfaces/component/FileUploadConstants.java
Log:
https://jira.jboss.org/jira/browse/RF-4761
Modified: trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequest.java
===================================================================
--- trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequest.java 2009-03-12 16:41:45 UTC (rev 12936)
+++ trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequest.java 2009-03-12 16:53:32 UTC (rev 12937)
@@ -81,8 +81,14 @@
private Map<String, Object> percentMap = null;
- private Map<String, MultipartRequest> requestsMap = null;
-
+ private Map<String, Integer> requestSizeMap = null;
+
+ private Map<String, String> requestKeysMap = null;
+
+ private String requestKey = null;
+
+ private MultipartRequestRegistry requestRegistry;
+
private List<String> keys = new ArrayList<String>();
private enum ReadState {
@@ -613,9 +619,28 @@
}
}
+ public static MultipartRequest lookupRequest(FacesContext context, String uploadId) {
+ Map<String, Object> sessionMap = context.getExternalContext().getSessionMap();
+ Map<String, String> requestKeys = (Map<String, String>) sessionMap.get(FileUploadConstants.REQUEST_KEYS_BEAN_NAME);
+ if (requestKeys != null) {
+ String requestKey = requestKeys.get(uploadId);
+ if (requestKey != null) {
+ MultipartRequestRegistry requestRegistry = MultipartRequestRegistry.getInstance(context);
+ if (requestRegistry != null) {
+ MultipartRequest request = requestRegistry.getRequest(requestKey);
+ if (request != null) {
+ return request;
+ }
+ }
+ }
+ }
+
+ return null;
+ }
+
@SuppressWarnings("unchecked")
private void setupProgressData() {
- if (percentMap == null || requestsMap == null) {
+ if (percentMap == null || requestSizeMap == null || requestKeysMap == null) {
FacesContext facesContext = FacesContext.getCurrentInstance();
if (facesContext != null) {
ExternalContext externalContext = facesContext.getExternalContext();
@@ -631,18 +656,34 @@
percentMap = new ConcurrentHashMap<String, Object>();
sessionMap.put(FileUploadConstants.PERCENT_BEAN_NAME, percentMap);
}
- percentMap.put(uploadId, Double.valueOf(0));
}
- if (requestsMap == null) {
- requestsMap = (Map<String, MultipartRequest>) sessionMap.get(FileUploadConstants.REQUESTS_SESSIONS_BEAN_NAME);
- if (requestsMap == null) {
- requestsMap = new ConcurrentHashMap<String, MultipartRequest>();
- sessionMap.put(FileUploadConstants.REQUESTS_SESSIONS_BEAN_NAME, requestsMap);
+ if (requestSizeMap == null) {
+ requestSizeMap = (Map<String, Integer>) sessionMap.get(FileUploadConstants.REQUEST_SIZE_BEAN_NAME);
+ if (requestSizeMap == null) {
+ requestSizeMap = new ConcurrentHashMap<String, Integer>();
+ sessionMap.put(FileUploadConstants.REQUEST_SIZE_BEAN_NAME, requestSizeMap);
}
- requestsMap.put(uploadId, this);
}
+
+ if (requestKeysMap == null) {
+ requestKeysMap = (Map<String, String>) sessionMap.get(FileUploadConstants.REQUEST_KEYS_BEAN_NAME);
+ if (requestKeysMap == null) {
+ requestKeysMap = new ConcurrentHashMap<String, String>();
+ sessionMap.put(FileUploadConstants.REQUEST_KEYS_BEAN_NAME, requestKeysMap);
+ }
+
+ }
}
+
+ percentMap.put(uploadId, Double.valueOf(0));
+
+ requestSizeMap.put(uploadId, getSize());
+
+ requestRegistry = MultipartRequestRegistry.getInstance(facesContext);
+ requestKey = requestRegistry.registerRequest(this);
+ requestKeysMap.put(uploadId, requestKey);
+
}
}
}
@@ -916,8 +957,16 @@
percentMap.remove(uploadId);
}
- if (requestsMap != null) {
- requestsMap.remove(uploadId);
+ if (requestSizeMap != null) {
+ requestSizeMap.remove(uploadId);
}
+
+ if (requestKeysMap != null) {
+ requestKeysMap.remove(uploadId);
+ }
+
+ if (requestRegistry != null) {
+ requestRegistry.removeRequest(requestKey);
+ }
}
}
Added: trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java
===================================================================
--- trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java (rev 0)
+++ trunk/framework/impl/src/main/java/org/ajax4jsf/request/MultipartRequestRegistry.java 2009-03-12 16:53:32 UTC (rev 12937)
@@ -0,0 +1,80 @@
+/**
+ * License Agreement.
+ *
+ * JBoss RichFaces - Ajax4jsf Component Library
+ *
+ * Copyright (C) 2007 Exadel, Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License version 2.1 as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+package org.ajax4jsf.request;
+
+import java.util.Map;
+import java.util.UUID;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.atomic.AtomicInteger;
+
+import javax.faces.context.FacesContext;
+
+/**
+ * @author Nick Belaevski
+ * @since 3.3.1
+ */
+
+public class MultipartRequestRegistry {
+
+ private AtomicInteger atomicInteger = new AtomicInteger(0);
+
+ private String registryId = UUID.randomUUID().toString();
+
+ private Map<String, MultipartRequest> requestsMap = new ConcurrentHashMap<String, MultipartRequest>();
+
+ private static final String REGISTRY_ATTRIBUTE_NAME = MultipartRequestRegistry.class.getName();
+
+ private MultipartRequestRegistry() {
+
+ }
+
+ public static MultipartRequestRegistry getInstance(FacesContext context) {
+ Map<String, Object> applicationMap = context.getExternalContext().getApplicationMap();
+ MultipartRequestRegistry requestRegistry = (MultipartRequestRegistry) applicationMap.get(REGISTRY_ATTRIBUTE_NAME);
+ if (requestRegistry == null) {
+ synchronized (applicationMap) {
+ requestRegistry = (MultipartRequestRegistry) applicationMap.get(REGISTRY_ATTRIBUTE_NAME);
+ if (requestRegistry == null) {
+ requestRegistry = new MultipartRequestRegistry();
+ applicationMap.put(REGISTRY_ATTRIBUTE_NAME, requestRegistry);
+ }
+ }
+ }
+
+ return requestRegistry;
+ }
+
+ public String registerRequest(MultipartRequest request) {
+ String key = registryId + ":" + atomicInteger.incrementAndGet();
+ requestsMap.put(key, request);
+
+ return key;
+ }
+
+ public void removeRequest(String key) {
+ requestsMap.remove(key);
+ }
+
+ public MultipartRequest getRequest(String key) {
+ return requestsMap.get(key);
+ }
+}
Modified: trunk/framework/impl/src/main/java/org/richfaces/component/FileUploadConstants.java
===================================================================
--- trunk/sandbox/ui/layout/src/main/resources/META-INF/themes/violetRays.theme.properties (rev 0)
+++ trunk/sandbox/ui/layout/src/main/resources/META-INF/themes/violetRays.theme.properties 2009-03-12 16:41:45 UTC (rev 12936)
@@ -0,0 +1,2 @@
+rendererType=org.richfaces.VioletRaysRenderer
+styleSheet=resource:///org/richfaces/renderkit/html/css/violetRays.xcss
Property changes on: trunk/sandbox/ui/layout/src/main/resources/META-INF/themes/violetRays.theme.properties
___________________________________________________________________
Name: svn:mime-type
+ text/plain
Name: svn:eol-style
+ native
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/css/violetRays.xcss
===================================================================
--- trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/css/violetRays.xcss (rev 0)
+++ trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/css/violetRays.xcss 2009-03-12 16:41:45 UTC (rev 12936)
@@ -0,0 +1,386 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+<f:template xmlns:f='http:/jsf.exadel.com/template'
+ xmlns:u='http:/jsf.exadel.com/template/util'
+ xmlns="http://www.w3.org/1999/xhtml">
+
+ <f:verbatim>
+ <![CDATA[
+body {
+ margin: 0;
+ background: #7A287A none repeat left top;
+ font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
+ font-size: 13px;
+ color: #C752C7;
+}
+
+h1, h2, h3 {
+ margin: 0;
+ font-family: Georgia, "Times New Roman", Times, serif;
+ font-weight: normal;
+ color: #649632;
+}
+
+h1 { font-size: 44px; }
+
+h2 { font-size: 20px; }
+
+h3 { }
+
+p, ul, ol {
+ margin-top: 0;
+ line-height: 240%;
+ text-align: justify;
+ font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
+ font-size: 11px;
+}
+
+ul, ol { }
+
+blockquote { }
+
+a { color: #FFFFFF; }
+
+a:hover { text-decoration: none; }
+
+a img {
+ border: none;
+}
+
+img.left {
+ float: left;
+ margin: 7px 30px 0 0;
+}
+
+img.right {
+ float: right;
+ margin: 7px 0 0 30px;
+}
+
+hr { display: none; }
+
+.list1 {
+}
+
+.list1 li {
+ float: left;
+ line-height: normal;
+}
+
+.list1 li img {
+ margin: 0 30px 30px 0;
+}
+
+.list1 li.alt img {
+ margin-right: 0;
+}
+
+#wrapper {
+ background: none repeat-x left top;
+ padding-top: 30px;
+}
+
+/* Header */
+
+#header-wrapper {
+}
+
+#header {
+ width: 913px;
+ height: 71px;
+ margin: 0 auto;
+
+ padding-top:10px;
+ text-align:center;
+ background: none no-repeat left top;
+}
+
+/* Search */
+
+#search {
+ float: right;
+ width: 305px;
+ height: 76px;
+}
+
+#search form {
+ float: right;
+ margin: 0;
+ padding: 35px 20px 0 0;
+}
+
+#search fieldset {
+ margin: 0;
+ padding: 0;
+ border: none;
+}
+
+#search input {
+ float: left;
+ font: 12px Georgia, "Times New Roman", Times, serif;
+ border: none;
+}
+
+#search-text {
+ width: 135px;
+ height: 18px;
+ padding: 3px 0 0 5px;
+ background: #ECF9E4;
+ color: #658453;
+}
+
+#search-submit {
+ height: 21px;
+ margin-left: 12px;
+ color: #39561D;
+}
+
+/* Page */
+
+#page {
+ width: 913px;
+ margin: 0 auto;
+ padding: 30px 0px 0px 0px;
+ background: #180818;
+}
+
+/** LOGO */
+
+#logo {
+ width: 913px;
+ height: 200px;
+ margin: 0 auto;
+ background: #180818;
+}
+
+#logo h1, #logo p {
+ margin: 0;
+ padding: 0 0 0 20px;
+ line-height: normal;
+}
+
+#logo h1 {
+ padding-top: 70px;
+}
+
+#logo h1 a {
+ text-decoration: none;
+ text-transform: lowercase;
+ color: #FFFFFF;
+}
+
+#logo h1 a:hover { text-decoration: underline; }
+
+#logo h2 {
+ padding: 0;
+ margin: 0;
+}
+
+#logo p {
+ padding: 0px 0 0 20px;
+ font: italic 13px Georgia, "Times New Roman", Times, serif;
+ color: #FFFFFF;
+}
+
+#logo p a {
+ text-decoration: none;
+ color: #FFFFFF;
+}
+
+#logo p a:hover { text-decoration: underline; }
+
+/* Content */
+
+#content {
+ float: right;
+ width: 600px;
+}
+
+/* Post */
+
+.post {
+ margin-bottom: 25px;
+}
+
+.post .title {
+ height: 30px;
+ margin-bottom: 3px;
+ padding: 8px 0px 2px 20px;
+ background: #230C23;
+ color: #FFFFFF;
+}
+
+.post .date {
+ float: right;
+ margin-top: 0;
+ padding-right: 20px;
+ font-family: Georgia, "Times New Roman", Times, serif;
+ font-weight: normal;
+ font-size: 18px;
+ color: #DB44DB;
+}
+
+.post .meta {
+ margin: 0 0 3px 25px;
+ padding: 2px 30px 2px 0px;
+ font-family: Arial, Helvetica, sans-serif;
+ font-weight: normal;
+ font-size: 10px;
+ color: #B6ACA2;
+}
+
+.post .meta a { color: #B6ACA2; }
+
+.post .entry {
+ padding: 25px 20px 0px 20px;
+}
+
+.post .links {
+ margin: 0 250px 0 0;
+ padding: 0 0 0 0px;
+}
+
+.post .links .comments {
+}
+
+.post .links .permalink {
+ padding-left: 17px;
+}
+
+/* Sidebar */
+
+#sidebar {
+ float: left;
+ width: 280px;
+}
+
+#sidebar ul {
+ margin: 0;
+ padding: 0;
+ list-style: none;
+ line-height: normal;
+}
+
+#sidebar li {
+ margin-bottom: 30px;
+ padding: 0 0 20px 0px;
+}
+
+#sidebar li ul {
+ line-height: 200%;
+}
+
+#sidebar li li {
+ margin: 0;
+ padding: 0 20px;
+}
+
+#sidebar p {
+ margin: 0;
+ padding: 0 20px;
+}
+
+#sidebar h2 {
+ height: 30px;
+ margin-bottom: 3px;
+ padding: 8px 0px 2px 20px;
+ background: #230C23;
+ font-size: 20px;
+ color: #FFFFFF;
+}
+
+
+#sidebar p {
+ line-height: 200%;
+}
+
+/* Calendar */
+
+#calendar {
+}
+
+#calendar caption {
+ padding-bottom: 5px;
+ font-weight: bold;
+}
+
+#calendar table {
+ width: 90%;
+ border-collapse: collapse;
+ margin: 0 20px;
+}
+
+#calendar thead th {
+ padding: 5px 0;
+ text-align: center;
+}
+
+#calendar tbody td {
+ padding: 5px 0;
+ text-align: center;
+}
+
+#calendar tfoot td {
+ padding: 5px;
+}
+
+#calendar tfoot #next {
+ text-align: right;
+}
+
+#calendar #today {
+}
+
+/* Footer */
+
+#footer {
+ width: 913px;
+ margin: 0 auto;
+ padding: 0;
+ text-align:center;
+ padding-top:20px;
+ background: none no-repeat left top;
+ height: 80px;
+}
+
+#footer p {
+ margin: 0;
+ padding: 20px 0;
+ text-align: center;
+ line-height: normal;
+ color: #FFFFFF;
+}
+
+#footer a {
+ color: #C752C7;
+}
+
+ ]]>
+ </f:verbatim>
+
+
+
+ <u:selector name="body">
+ <u:style name="background-image">
+ <f:resource f:key="/org/richfaces/renderkit/html/images/violet/img02.jpg" />
+ </u:style>
+ </u:selector>
+
+ <u:selector name="#wrapper">
+ <u:style name="background-image">
+ <f:resource f:key="/org/richfaces/renderkit/html/images/violet/img01.jpg" />
+ </u:style>
+ </u:selector>
+ <u:selector name="#header">
+ <u:style name="background-image">
+ <f:resource f:key="/org/richfaces/renderkit/html/images/violet/img03.jpg" />
+ </u:style>
+ </u:selector>
+
+ <u:selector name="#footer">
+ <u:style name="background-image">
+ <f:resource f:key="/org/richfaces/renderkit/html/images/violet/img04.jpg" />
+ </u:style>
+ </u:selector>
+
+</f:template>
\ No newline at end of file
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/tempGradient.jpg
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/tempGradient.jpg
___________________________________________________________________
Name: svn:mime-type
+ image/jpeg
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img01.jpg
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img01.jpg
___________________________________________________________________
Name: svn:mime-type
+ image/jpeg
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img02.jpg
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img02.jpg
___________________________________________________________________
Name: svn:mime-type
+ image/jpeg
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img03.jpg
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img03.jpg
___________________________________________________________________
Name: svn:mime-type
+ image/jpeg
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img04.jpg
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img04.jpg
___________________________________________________________________
Name: svn:mime-type
+ image/jpeg
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img05.gif
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img05.gif
___________________________________________________________________
Name: svn:mime-type
+ image/gif
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img06.jpg
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img06.jpg
___________________________________________________________________
Name: svn:mime-type
+ image/jpeg
Added: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/spacer.gif
===================================================================
(Binary files differ)
Property changes on: trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/spacer.gif
___________________________________________________________________
Name: svn:mime-type
+ image/gif
Added: trunk/sandbox/ui/layout/src/main/templates/org/richfaces/violetRays.jspx
===================================================================
--- trunk/sandbox/ui/layout/src/main/templates/org/richfaces/violetRays.jspx (rev 0)
+++ trunk/sandbox/ui/layout/src/main/templates/org/richfaces/violetRays.jspx 2009-03-12 16:41:45 UTC (rev 12936)
@@ -0,0 +1,78 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<f:root
+ xmlns:f="http://ajax4jsf.org/cdk/template"
+ xmlns:c=" http://java.sun.com/jsf/core"
+ xmlns:ui=" http://ajax4jsf.org/cdk/ui"
+ xmlns:u=" http://ajax4jsf.org/cdk/u"
+ xmlns:x=" http://ajax4jsf.org/cdk/x"
+ xmlns:h="http://jsf.exadel.com/header"
+ xmlns:vcp="http://ajax4jsf.org/cdk/vcp"
+ class="org.richfaces.renderkit.html.VioletRaysRenderer"
+ baseclass="org.richfaces.renderkit.AbstractPageRenderer"
+ component="org.richfaces.component.UIPage"
+ >
+ <c:set var="namespace" value="#{this:prolog(context,component)}"/>
+ <html x:xmlns="#{namespace}" x:lang="#{context.viewRoot.locale}"
+ >
+<head>
+<meta http-equiv="content-type" content="text/html; charset=utf-8" />
+ <title>#{component.attributes['pageTitle']}</title>
+ <f:call name="themeStyle"/>
+ <f:call name="themeScript"/>
+ <u:insertFacet name="pageHeader"/>
+
+</head>
+<body x:passThruWithExclusions="value,name,type,id">
+<div id="wrapper">
+
+<div id="header">
+ <c:if test="#{this:hasFacet(component,'header')}">
+ <div id="#{clientId}:hd" class="rich-page-header #{component.attributes['headerClass']}">
+ <u:insertFacet name="header"/>
+ </div>
+ </c:if>
+
+</div>
+<!-- end #header -->
+<!--div id="logo"-->
+<!--/div-->
+<hr />
+<!-- end #logo -->
+<!-- end #header-wrapper -->
+
+<div id="page">
+ <div id="content">
+ <vcp:body>
+ <div class="rich-page-body #{component.attributes['bodyClass']}">
+ <f:call name="renderChildren" />
+ </div>
+ </vcp:body>
+ </div>
+
+ <!-- end #content -->
+ <div id="sidebar">
+
+ <c:if test="#{this:hasFacet(component,'sidebar')}">
+ <div class="rich-page-sidebar #{component.attributes['styleClass']}">
+ <u:insertFacet name="sidebar"/>
+ </div>
+ </c:if>
+ </div>
+ <!-- end #sidebar -->
+ <div style="clear: both;"></div>
+ </div>
+<!-- end #page -->
+</div>
+ <div id="footer">
+ <c:if test="#{this:hasFacet(component,'footer')}">
+ <f:clientid var="clientId"/>
+ <div id="#{clientId}:ft" class="rich-page-footer #{component.attributes['footerClass']}">
+ <u:insertFacet name="footer"/>
+ </div>
+ </c:if>
+
+ </div>
+<!-- end #footer -->
+</body>
+</html>
+</f:root>
\ No newline at end of file
15 years, 10 months
--- trunk/framework/impl/src/main/java/org/richfaces/component/FileUploadConstants.java 2009-03-12 16:41:45 UTC (rev 12936)
+++ trunk/framework/impl/src/main/java/org/richfaces/component/FileUploadConstants.java 2009-03-12 16:53:32 UTC (rev 12937)
@@ -40,12 +40,17 @@
/** Request parameter name indicated that file was uploaded by RF component */
public static final String FILE_UPLOAD_INDICATOR = "_richfaces_upload_file_indicator";
- /** Session bean name where multipart requests map will be stored */
- public static final String REQUESTS_SESSIONS_BEAN_NAME = "_richfaces_upload_sessions";
+ /** Session bean name where request size will be stored */
+ public static final String REQUEST_SIZE_BEAN_NAME = "_richfaces_request_size";
/** Session bean name where progress bar's percent map will be stored */
public static final String PERCENT_BEAN_NAME = "_richfaces_upload_percents";
+ /** Session bean name where stop keys will be stored */
+ public static final String REQUEST_KEYS_BEAN_NAME = "_richfaces_request_keys";
+
+ public static final String FILE_UPLOAD_ACTION_STOP = "richfaces_file_upload_action_stop";
+
private FileUploadConstants() {
//private constructor
}
15 years, 10 months
JBoss Rich Faces SVN: r12936 - in trunk/sandbox/ui/layout/src/main: resources/org/richfaces/renderkit/html/css and 3 other directories.
by richfaces-svn-commits@lists.jboss.org
Author: SergeySmirnov
Date: 2009-03-12 12:41:45 -0400 (Thu, 12 Mar 2009)
New Revision: 12936
Added:
trunk/sandbox/ui/layout/src/main/resources/META-INF/themes/violetRays.theme.properties
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/css/violetRays.xcss
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/tempGradient.jpg
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img01.jpg
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img02.jpg
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img03.jpg
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img04.jpg
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img05.gif
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/img06.jpg
trunk/sandbox/ui/layout/src/main/resources/org/richfaces/renderkit/html/images/violet/spacer.gif
trunk/sandbox/ui/layout/src/main/templates/org/richfaces/violetRays.jspx
Log:
Violet Example
Added: trunk/sandbox/ui/layout/src/main/resources/META-INF/themes/violetRays.theme.properties
===================================================================